@@ -67,7 +67,7 @@ else:
             mutex: Any = None,
             exclusive: bool = False
         ) -> None:
-            self.shor: str = short
+            self.short: str = short
             self.long: str = long
             self.default: Any = default
             self.docs: str = docs
@@ -314,7 +314,7 @@ class Parser:
                 continue
 
             if argument.count == 1:
-                self.add_option(argument, True)
+                self.add_option(argument, argv[index])
                 index += 1
                 continue
 
@@ -402,7 +402,7 @@ class Command(metaclass=CommandMeta):
 
     def run(self, options: Options, remains: List[str]) -> NoReturn:
         raise NotImplementedError(
-            'subclass of "Command" must provide a'
+            'subclass of "Command" must provide a '
             'run(options, remains) method'
         )     
 
